;; Generated package description from helm-core.el  -*- no-byte-compile: t; lexical-binding:t -*-
(define-package "helm-core" "4.0.7.0.20260720.27" "Development files for Helm" '((emacs "25.1") (async "1.9.9")) :commit "ab09703effe69217b97a2097ff3b8742bb39c6a3" :authors '(("Thierry Volpiatto" . "thievol@posteo.net")) :maintainer '("Thierry Volpiatto" . "thievol@posteo.net") :url "https://emacs-helm.github.io/helm/")
